from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.RepeatedCapability import RepeatedCapability
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SccCls:
	"""Scc commands group definition. 8 total commands, 5 Subgroups, 0 group commands
	Repeated Capability: SecondaryCompCarrier, default value after init: SecondaryCompCarrier.CC1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("scc", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_secondaryCompCarrier_get', 'repcap_secondaryCompCarrier_set', repcap.SecondaryCompCarrier.CC1)

	def repcap_secondaryCompCarrier_set(self, secondaryCompCarrier: repcap.SecondaryCompCarrier) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to SecondaryCompCarrier.Default
		Default value after init: SecondaryCompCarrier.CC1"""
		self._cmd_group.set_repcap_enum_value(secondaryCompCarrier)

	def repcap_secondaryCompCarrier_get(self) -> repcap.SecondaryCompCarrier:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def rsrp(self):
		"""rsrp commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_rsrp'):
			from .Rsrp import RsrpCls
			self._rsrp = RsrpCls(self._core, self._cmd_group)
		return self._rsrp

	@property
	def rsrq(self):
		"""rsrq commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_rsrq'):
			from .Rsrq import RsrqCls
			self._rsrq = RsrqCls(self._core, self._cmd_group)
		return self._rsrq

	@property
	def scell(self):
		"""scell commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_scell'):
			from .Scell import ScellCls
			self._scell = ScellCls(self._core, self._cmd_group)
		return self._scell

	@property
	def cocc(self):
		"""cocc commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cocc'):
			from .Cocc import CoccCls
			self._cocc = CoccCls(self._core, self._cmd_group)
		return self._cocc

	@property
	def rresult(self):
		"""rresult commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rresult'):
			from .Rresult import RresultCls
			self._rresult = RresultCls(self._core, self._cmd_group)
		return self._rresult

	def clone(self) -> 'SccCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SccCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group
